@@ -65,6 +65,16 @@
   ("/ /" "//")
   ("/ / var" (make 'deleted))
 
+  ;; Markdown Style Shortcuts
+  ("# # var" (make 'section))
+  ("# # # var" (make 'subsection))
+  ("# # # # var" (make 'subsubsection))
+  ("` ` ` var" (make 'verbatim-code))
+  ("* * var" (make-with "font-series" "bold"))
+  ("* var" (make-with "font-shape" "italic"))
+  ("+ var" (make-tmlist 'itemize))
+  ("1 . var" (make-tmlist 'enumerate))
+
   ("space var" (make 'nbsp))
   ("space var var" (make-space "1em"))
   ("_" "_")
@@ -339,6 +349,13 @@
   ("n var" "<#0144>")
   ("n var var" "<#0148>")
   ("n var var var" "<#01F9>")
+  (". var" "<#3002>")
+  (": var" "<#FF1A>")
+  ("; var" "<#FF1B>")
+  (", var" "<#FF0C>")
+  ("( var" "<#FF08>")
+  (") var" "<#FF09>")
+  ("? var" "<#FF1F>")
   ("< var" "<#300A>")
   ("> var" "<#300B>")
   ("' var" "<#2018>")
@@ -546,7 +563,7 @@
   ("text $" (make-equation*))
   ("text &" (make-eqnarray*))
 
-  ("text a" (make-small 'abbr))
+  ("text a" (make 'abbr))
   ("text d" (make-tmlist 'description))
   ("text e" (make-tmlist 'enumerate))
   ("text i" (make-tmlist 'itemize))
