@@ -195,7 +195,8 @@
   ("Pseudo code" (make 'render-code))
   ---
   ("Indent" (make 'indent))
-  ("Tabbed" (make 'tabbed))
+  (when (not (selection-active?))
+    ("Tabbed" (make 'wide-tabbed)))
   ---
   (-> "Inline code"
       ("C++" (make 'cpp))
@@ -224,17 +225,28 @@
 
 (menu-bind note-menu
   (when (not (or (inside? 'float) (inside? 'footnote)))
-    ("Footnote" (make 'footnote))
-    ("Marginal note" (make-marginal-note))
+    ("Footnote" (make-wrapped 'footnote))
+    (when (not (selection-active-non-small?))
+      ("Marginal note" (make-marginal-note)))
     ;;("Balloon" (make-balloon))
     ---
     ("Floating object" (make-insertion "float"))
-    ("Floating phantom" (insert '(phantom-float "float" "hf")))
-    ("Floating figure" (begin (make-insertion "float") (make 'big-figure)))
-    ("Floating table" (begin (make-insertion "float")
-                             (insert-go-to '(big-table "" "") '(0 0))
-                             (make 'tabular)))
-    ("Floating algorithm" (begin (make-insertion "float") (make 'algorithm)))))
+    (when (not (selection-active-non-small?))
+      ("Floating phantom" (insert '(phantom-float "float" "hf"))))
+    (when (not (selection-active-non-small?))
+      ("Floating figure"
+       (wrap-selection-small
+         (make-insertion "float")
+         (insert-go-to '(big-figure "" (document "")) '(0 0))))
+      ("Floating table"
+       (wrap-selection-small
+         (make-insertion "float")
+         (insert-go-to '(big-table "" (document "")) '(0 0))
+         (make 'tabular))))
+    ("Floating algorithm"
+     (wrap-selection-any
+       (make-insertion "float")
+       (make 'algorithm)))))
 
 (menu-bind position-marginal-note-menu
   (group "Horizontal position")
@@ -331,7 +343,8 @@
   ("Name" (make 'name))
   ("Person" (make 'person))
   ("Cite" (make 'cite*))
-  ("Abbreviation" (make-small 'abbr))
+  (when (not (selection-active-non-small?))
+    ("Abbreviation" (make 'abbr)))
   ("Acronym" (make 'acronym))
   ---
   ("Verbatim" (make 'verbatim))
@@ -434,6 +447,11 @@
   ("Long" (make-tmlist 'description-long))
   ("Paragraphs" (make-tmlist 'description-paragraphs)))
 
+(menu-bind lists-menu
+  (-> "Itemize" (link itemize-menu))
+  (-> "Enumerate" (link enumerate-menu))
+  (-> "Description" (link description-menu)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Automatically generated content
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -486,9 +504,7 @@
       (-> "Automatic" (link automatic-menu)))
   (if (style-has? "std-list-dtd")
       ---
-      (-> "Itemize" (link itemize-menu))
-      (-> "Enumerate" (link enumerate-menu))
-      (-> "Description" (link description-menu))))
+      (link lists-menu)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Text menus for inserting inline content
